@@ -23,7 +23,7 @@ def security_middleware(xss='default'):
         if xss:
             # if xss - string -> looking in predifined data. Else -> this should be custom dict.
             csp_dict = CSP_DEFAULT.get(str(xss)) or xss
-            csp_string = csp_builder(xss_dict)
+            csp_string = csp_builder(csp_dict)
             request.headers['Content-Security-Policy'] = csp_string
 
         return await handler(request)
