@@ -1,3 +1,4 @@
+from collections.abc import Iterable
 
 def csp_builder(csp_dict: dict) -> str:
     """Builds CSP string from dictionary
@@ -12,10 +13,19 @@ def csp_builder(csp_dict: dict) -> str:
     return_str = ''
     for key, value in csp_dict.items():
         return_str += key
-        return_str += value if isinstance(value, str) else ' '.join(value) or ''
+        if isinstance(value, str):
+            return_str += value
+        elif isinstance(value, Iterable):
+            ' '.join(value)
+        elif value is None:
+            pass
+        else:
+            raise AttributeError(f'{key} should be either string or iterable or None')
+
         if return_str.isspace():  # all chars are whitespaces
             raise AttributeError(f'{key} configured incorrectly in CSP dictionary')
 
         return_str += ' ;'
 
     return return_str
+
